install.packages("R.oo")
library(R.oo)

source("http://www.umich.edu/~jowei/PresidentialAppointments/stag.R")	
z <- read.csv( "http://www.umich.edu/~jowei/PresidentialAppointments/Thomas_PLUM_merged_Nov2013.csv")

aglist <- read.delim("http://www.umich.edu/~jowei/PresidentialAppointments/30agencies.txt", header=F)	

agencies <- NA	

for (i in 1:length(aglist$V1)){	
agencies[i] <- stag(aglist$V1[i])[2]	
}	
agencies <- agencies[!is.na(agencies)]	
cf.ip <- NA	
cf.meds <- NA	
nc.ip <- NA	
nc.meds <- NA	
cf.n <- NA	
nc.n <- NA	

for (i in 1:length(agencies)){	
	conf <- z[z$appt=="SenConf" & z$AG==agencies[i] & z$pres=="clinton",]
	cf.ip[i] <- mean(conf$CONT.IPS, na.rm=T)
	cf.meds[i] <- median(conf$CONT.IPS, na.rm=T)
	cf.n[i] <- sum(!is.na(conf$CONT.IPS))

	nc <- z[z$appt!="SenConf" & z$AG==agencies[i] & z$pres=="clinton",]
	nc.ip[i] <- mean(nc$CONT.IPS, na.rm=T)
	nc.meds[i] <- median(nc$CONT.IPS, na.rm=T)
	nc.n[i] <- sum(!is.na(nc$CONT.IPS))

}	


q <- as.data.frame(cbind(agencies,cf.ip,nc.ip))	
q$cf.ip <- cf.ip	
q$nc.ip <- nc.ip	
q$cf.n <- cf.n	
q$nc.n <- nc.n	
q$cf.meds <- cf.meds	
q$nc.meds <- nc.meds	
zz <- z[z$appt=="SenConf",]
q$agname <- zz$mainagency[match(q$agencies,as.character(zz$AG))]	
q$agname <- as.character(q$agname)	
###############################################################	

qs <- q
qs$agency <- qs$agname
qs$agency <- as.character(qs$agency)
qs$agency[qs$agency=="United States International Development Cooperation Agency"] <- "International Development Cooperation Agency"
qs$agency[qs$agency=="Morris K. Udall Scholarship and Excellence in National Environmental Policy Foundation"] <- "Morris K. Udall Foundation"
qs$agency[qs$agency=="Defense Base Closure and Realignment Commission"] <- "Defense Base Closure and Realignment Comm'n"
qs$agency[qs$agency=="National Commission on Libraries and Information Science"] <- "Nat. Comm'n on Libraries and Information Science"
qs$agency[qs$agency=="United States Advisory Commission on Public Diplomacy"] <- "Advisory Commission on Public Diplomacy"
qs$agency[qs$agency=="National Commission on Libraries and Information Science"] <- "Nat. Comm'n on Libraries and Information Science"
qs$agency[qs$agency=="The Judiciary"] <- "Judicial Branch (Judicial Nominees)"
qs$agency[qs$agencies=="HS"] <- "Department of Homeland Security"
qs$agency[qs$agencies=="VA"] <- "Department of Veteran Affairs"
qs <- qs[rev(order(qs$cf.n)),]
qs <- qs[1:25,]
qs <- qs[rev(order(qs$agency)),]
k <- length(qs$agency)


postscript("Figure7.eps", height=6.5, width=8, horizontal=FALSE)

title <- "Comparison of Clinton Administration Nominees\nto Senate-Confirmed and Schedule C Positions"
par(mar=c(4.5,16.0,3.0,0.8))
plot(NA,NA, xlim=c(-1.4,0), ylim=c(1,(k+4.5)), yaxt="n",xaxt="n", ylab="", xlab="Mean Ideal Point")

points(qs$cf.ip, seq(1:k)   , col="blue", pch=16, cex=1.3)
points(qs$nc.ip, seq(1:k)   , col="red", pch=2, cex=1.3)

xlabs <- seq(from=-1.5,to=1.5,by=0.25)

axis(1, at=seq(from=-1.5,to=1.5,by=0.25), lab=xlabs,mgp=c(1.8, 0.6, 0), cex.axis=1, par(las=1))

axis(2, at=seq(1:k), lab=qs$agency,mgp=c(1.8, 0.6, 0), cex.axis=0.75, par(las=1))
for (i in 1:k){
lines(c(-10,10),c(i,i),lty="dashed")
}

legend("top", c("Mean Ideology, Senate-Confirmed Positions Nominees","Mean Ideology, Schedule C Position Nominees"),
 pch=c(16,2), cex=0.7, pt.cex=c(1,1), col=c("blue","red"), text.col=c("blue","red"), title.col=c("black"), title="Legend:",bty="y"##,lty=c(2,1)
)

title(main=title,
ylab="Agency"
, cex.main=0.85
, cex.lab=1.4
, mgp=c(14.6, 1.8, 0))


dev.off()
