##READ IN THOMAS_PLUM DATA WITH SALARIES MERGED (INCLUDES ONLY GW BUSH DATA)
z <- read.csv("http://www.umich.edu/~jowei/PresidentialAppointments/Thomas_PLUM_merged_FULL2013b.csv")

z$mainagency <- as.character(z$mainagency)
z$mainagency[as.character(z$mainagency)=="Department of Homeland Security"] <- "DHS"
z$mainagency[as.character(z$mainagency)=="Department of Veterans Affairs"] <- "VA"
z$mainagency[as.character(z$mainagency)=="DEPARTMENT OF HOUSING AND URBAN DEVELOPM"] <- "DEPARTMENT OF HOUSING AND URBAN DEVELOPMENT"



conf <- z[z$appt=="SenConf",]	
plot(conf$CONT.IPS ~ conf$salary)	
nc <- z[z$appt!="SenConf",]	
points(nc$CONT.IPS ~ nc$salary, col="red")	

step <- 25000	
mins <- seq(from=0, to=(150000-step), by=step)	
maxs <- mins+step	

cf.ip <- 0	
cf.meds <- 0	
cf.n <- NA
nc.ip <- 0	
nc.meds <- 0	
nc.n <- NA
for (i in 1:length(mins)){	
	conf <- z[z$appt=="SenConf" & z$salary>=mins[i] & z$salary<maxs[i],]
	cf.ip[i] <- mean(conf$CONT.IPS, na.rm=T)
	cf.meds[i] <- median(conf$CONT.IPS, na.rm=T)
	cf.n[i] <- sum(!is.na(conf$CONT.IPS))
	nc <- z[z$appt!="SenConf" & z$salary>=mins[i] & z$salary<maxs[i],]
	nc.ip[i] <- mean(nc$CONT.IPS, na.rm=T)
	nc.meds[i] <- median(nc$CONT.IPS, na.rm=T)
	nc.n[i] <- sum(!is.na(nc$CONT.IPS))
}	

yl <- c(-0.5,1.3)	
xaxis <- (mins+maxs)/2	

##PLOT THE MEAN IDEAL POINTS FOR EACH SALARY GROUP (FIGURE 10)
postscript("Figure10.eps", width=8, height=6.5, horizontal=FALSE)	

plot(cf.ip ~ xaxis, ylim=yl, col="red", type="b", xlab="", ylab="", pch=1, cex=1.4, xaxt="n")	
points(nc.ip ~ xaxis, ylim=yl, col="blue", type="b", pch=20, cex=1.4)

title("Average Ideal Points of G.W. Bush Administration's \nSenate-Confirmed and Non-Confirmed Appointees by Salary Range",
, ylab="Appointees' Average Ideal Points"
, xlab="Salary Range (2007 Fiscal Year)"
, cex.main=1.3
, cex.lab=1.4
, mgp=c(2.8, 1.8, 0))

step <- 25000
att <- seq(from=0, to=250000, by=step)
minlab <- paste("$", (mins/1000),",000" ,sep="")
minlab[1] <- "$0"
maxlab <- paste("$", (maxs/1000),",000" ,sep="")
alllabs <- paste(minlab," to \n",maxlab,sep="")
alllabs[length(alllabs)] <- paste("Over",minlab[length(alllabs)],sep="\n")
axis(1, at=xaxis, lab=alllabs, cex.axis=0.8, mgp=c(3.5, 1.40, 0))
axis(2, at=seq(-2,2,by=0.25), lab=seq(-2,2,by=0.25))
lines(c(0,10^8), c(0,0), lty="dashed")
legend("topleft", c("Non-Confirmed Appointees","Senate-Confirmed Appointees"), pch=c(20,1), cex=1, pt.cex=c(1.4,1.4), col=c("blue","red"), text.col=c("blue","red"), title.col=c("black"), title="Legend:",bty="y")
dev.off()




##SHOW DISTRIBUTION OF SALARIES
postscript("Figure2b.eps", horizontal=F, width=6, height=6)
hist((z[z$appt=="SenConf",])$salary, xlab="Salary (2007 Fiscal Year)", main="Histogram of Senate-Confirmed Appointees' Salaries", xaxt="n", xlim=c(0,250000), nclass=20)
step <- 50000
att <- seq(from=0, to=250000, by=step)
atlab <- paste("$", (att/1000),",000" ,sep="")
axis(1, at=att, lab=atlab)
dev.off()

postscript("Figure2a.eps", horizontal=F, width=6, height=6)
hist((z[z$appt!="SenConf",])$salary, xlab="Salary (2007 Fiscal Year)", main="Histogram of Non-Confirmed Appointees' Salaries", xaxt="n", xlim=c(0,250000), nclass=20)
step <- 25000
att <- seq(from=0, to=250000, by=step)
atlab <- paste("$", (att/1000),",000" ,sep="")
axis(1, at=att, lab=atlab)
dev.off()


##################TITLES FIGURE: (Figure 9)
titles <- names(rev(sort(summary(as.factor(z$title), maxsum=1000))))[2:52]

cf.ip <- NA
cf.meds <- NA
nc.ip <- NA
nc.meds <- NA
cf.n <- NA
nc.n <- NA

for (i in 1:length(titles)){
	conf <- z[z$appt=="SenConf" & z$title==titles[i],]
	cf.ip[i] <- mean(conf$CONT.IPS, na.rm=T)
	cf.meds[i] <- median(conf$CONT.IPS, na.rm=T)
	cf.n[i] <- sum(!is.na(conf$CONT.IPS))

	nc <- z[z$appt!="SenConf" & z$title==titles[i],]
	nc.ip[i] <- mean(nc$CONT.IPS, na.rm=T)
	nc.meds[i] <- median(nc$CONT.IPS, na.rm=T)
	nc.n[i] <- sum(!is.na(nc$CONT.IPS))

}	

q <- as.data.frame(cbind(titles,cf.ip,nc.ip))	
q$cf.ip <- cf.ip	
q$nc.ip <- nc.ip	
q$cf.n <- cf.n	
q$nc.n <- nc.n
q$cf.meds <- cf.meds
q$nc.meds <- nc.meds
q$n <- q$cf.n+q$nc.n
q <- q[q$n>0,]


q <- q[!is.na(q$cf.ip) & !is.na(q$nc.ip),]
q <- q[q$n>10,]
k <- length(q$titles)

plot(NA,NA, xlim=c(-1.5,1.5), ylim=c(0.5,(k+0.5)))
points(q$cf.meds, seq(1:k)   , col="blue", pch=1, type="b")
points(q$nc.meds, seq(1:k)   , col="red", pch=2, type="b")

q$titles <- as.character(q$titles)
q$titles[1] <- "MISCELLANEOUS ADMINISTRATION\nAND PROGRAM"


##PLOT THE MEAN IDEAL POINTS FOR EACH SALARY GROUP	
postscript("Figure9.eps", width=8, height=6.5, horizontal=FALSE)	

title <- "Ideal Points of Nominees to Occupational Classifications \n with Senate-Confirmed and Schedule C Positions"
par(mar=c(4.5,14.0,3.0,0.3))
plot(NA,NA, xlim=c(0,1), ylim=c(0.5,(k+1.5)), yaxt="n", ylab="", xlab="Mean Ideal Point")

points(q$cf.ip, seq(1:k)   , col="blue", pch=16, cex=1.5)
points(q$nc.ip, seq(1:k)   , col="red", pch=2, cex=2)
axis(2, at=seq(1:k), lab=q$titles,mgp=c(1.8, 0.6, 0), cex.axis=0.8, par(las=1), main="test")
for (i in 1:k){
lines(c(-10,10),c(i,i),lty="dashed")
}

legend("top", c("Mean Ideal Point of Nominees to Senate-Confirmed Positions","Mean Ideal Point of Nominees to Schedule C Positions"),
 pch=c(16,2), cex=0.9, pt.cex=c(1.5,2), col=c("blue","red"), text.col=c("blue","red"), title.col=c("black"), title="Legend:",bty="y"##,lty=c(2,1)
)

title(main=title,
ylab="OPM Occupational Classifications"
, cex.main=1.15
, cex.lab=1.4
, mgp=c(12.6, 1.8, 0))
dev.off()
